searchData={"items":[{"type":"module","title":"Syrup","doc":"A Syrup parser and generator in pure Elixir.\n\nSyrup is a simple data serialization format that is easy to read and write by humans.\n\nSee the `Syrup.Encoder` module for information on implementing the protocol for structures.","ref":"Syrup.html"},{"type":"function","title":"Syrup.as_binary/1","doc":"Forces encoding a value as a Syrup binary.","ref":"Syrup.html#as_binary/1"},{"type":"function","title":"Syrup.as_record/1","doc":"Forces encoding a value as a Syrup record.\n\nThis is mostly useful if\nthe tuple might be interpreted as forcing a particular encoding.\nFor example, `as_record(as_string(\"foo\"))` will result in encoding\nthe record `{:string, \"foo\"}` rather than the string `\"foo\"`.","ref":"Syrup.html#as_record/1"},{"type":"function","title":"Syrup.as_string/1","doc":"Forces encoding a value as a Syrup string.","ref":"Syrup.html#as_string/1"},{"type":"function","title":"Syrup.decode/2","doc":"Parses a Syrup value from `input` iodata.","ref":"Syrup.html#decode/2"},{"type":"function","title":"Options - Syrup.decode/2","doc":"* `:symbols` - controls how symbols are decoded. Possible values are:\n  * `:strings` (default) - decodes symbols as binary strings\n  * `:atoms` - decodes symbols as atoms using `String.to_atom/1`\n  * `:atoms!` - decodes symbols as atoms using `String.to_existing_atom/1`\n  * `:tuples` - decodes symbols as tuples with the first element being `:symbol`","ref":"Syrup.html#decode/2-options"},{"type":"function","title":"Decoding symbols to atoms - Syrup.decode/2","doc":"The `:atoms` option uses the `String.to_atom/1` call that can create atoms at runtime.\nSince the atoms are not garbage collected, this can pose a DoS attack vector when used\non user-controlled data.","ref":"Syrup.html#decode/2-decoding-symbols-to-atoms"},{"type":"function","title":"Examples - Syrup.decode/2","doc":"iex> Syrup.decode(\"{}\")\n    {:ok, %{}}\n\n    iex> Syrup.decode(\"invalid\")\n    {:error, %Syrup.DecodeError{message: \"invalid data\"}}","ref":"Syrup.html#decode/2-examples"},{"type":"function","title":"Syrup.decode!/2","doc":"Parses a Syrup value from `input` iodata.\n\nRaises an exception if the input is invalid.","ref":"Syrup.html#decode!/2"},{"type":"function","title":"Syrup.encode/2","doc":"Encodes a value to Syrup.","ref":"Syrup.html#encode/2"},{"type":"function","title":"Options - Syrup.encode/2","doc":"* `:binaries` - controls how binaries are encoded. Possible values are:\n  * `:strings` (default) - encodes Elixir binaries as Syrup strings if they are valid UTF-8 sequences\n  * `:binaries` - encodes Elixir binaries as Syrup binaries regardless of their UTF-8 validity","ref":"Syrup.html#encode/2-options"},{"type":"function","title":"Syrup.encode!/2","doc":"","ref":"Syrup.html#encode!/2"},{"type":"module","title":"Syrup.Encode","doc":"Utilities for encoding elixir values to Syrup.","ref":"Syrup.Encode.html"},{"type":"function","title":"Syrup.Encode.atom/1","doc":"","ref":"Syrup.Encode.html#atom/1"},{"type":"function","title":"Syrup.Encode.binary!/2","doc":"","ref":"Syrup.Encode.html#binary!/2"},{"type":"function","title":"Syrup.Encode.float/2","doc":"","ref":"Syrup.Encode.html#float/2"},{"type":"function","title":"Syrup.Encode.integer/1","doc":"","ref":"Syrup.Encode.html#integer/1"},{"type":"function","title":"Syrup.Encode.keyword/2","doc":"","ref":"Syrup.Encode.html#keyword/2"},{"type":"function","title":"Syrup.Encode.list/2","doc":"","ref":"Syrup.Encode.html#list/2"},{"type":"function","title":"Syrup.Encode.map/2","doc":"","ref":"Syrup.Encode.html#map/2"},{"type":"function","title":"Syrup.Encode.record/2","doc":"","ref":"Syrup.Encode.html#record/2"},{"type":"function","title":"Syrup.Encode.set/2","doc":"","ref":"Syrup.Encode.html#set/2"},{"type":"function","title":"Syrup.Encode.string/2","doc":"","ref":"Syrup.Encode.html#string/2"},{"type":"function","title":"Syrup.Encode.string!/2","doc":"","ref":"Syrup.Encode.html#string!/2"},{"type":"opaque","title":"Syrup.Encode.opts/0","doc":"","ref":"Syrup.Encode.html#t:opts/0"},{"type":"protocol","title":"Syrup.Encoder","doc":"Protocol controlling how a value is encoded to Syrup.","ref":"Syrup.Encoder.html"},{"type":"protocol","title":"Deriving - Syrup.Encoder","doc":"The protocol allows leveraging Elixir's `@derive` feature\nto simplify protocol implementtaion in trivial cases. Accepted\noptions are:\n\n  * `:only` - encodes only values of specific keys.\n  * `:except` - encodes all struct fields except specific keys.\n  * `:as` - the type of the encoding to use. Can be `:map` or `:record`.\n  * `:label` - record name to use instead of the struct name if serializing as a record.\n\nBy default all keys except the `:__struct__` key are encoded.","ref":"Syrup.Encoder.html#module-deriving"},{"type":"protocol","title":"Example - Syrup.Encoder","doc":"Let's assume a presence of the following struct:\n\n    defmodule Test do\n      defstruct [:foo, :bar, :baz]\n    end\n\nIf we were to call `@derive Syrup.Encoder` just before `defstruct`,\nan implementation similar to the following implementation would be generated:\n\n    defimpl Syrup.Encoder, for: Test do\n      def encode(value, opts) do\n        Syrup.Encode.record(Map.take(value, [:foo, :bar, :baz]), Keyword.put_new(opts, :as, \"Test\"))\n      end\n    end\n\nIf we called `@derive {Syrup.Encoder, only: [:foo]}`, an implementation\nsimilar to the following implementation would be generated:\n\n    defimpl Syrup.Encoder, for: Test do\n      def encode(value, opts) do\n        Syrup.Encode.record(Map.take(value, [:foo]), Keyword.put_new(opts, :as, \"Test\"))\n      end\n    end\n\nIf we called `@derive {Syrup.Encoder, except: [:foo]}`, an implementation\nsimilar to the following implementation would be generated:\n\n    defimpl Syrup.Encoder, for: Test do\n      def encode(value, opts) do\n        Syrup.Encode.record(Map.take(value, [:bar, :baz]), Keyword.put_new(opts, :as, \"Test\"))\n      end\n    end\n\nIf we called `@derive {Syrup.Encoder, as: \"test\"}`, an implementation\nsimilar to the following implementation would be generated:\n\n    defimpl Syrup.Encoder, for: Test do\n      def encode(value, opts) do\n        Syrup.Encode.record(Map.take(value, [:foo, :bar, :baz]), Keyword.put_new(opts, :as, \"test\"))\n      end\n    end\n\nThe actually generated implementations are more efficient computing some data\nduring compilation similar to the macros from the `Syrup.Helpers` module.","ref":"Syrup.Encoder.html#module-example"},{"type":"protocol","title":"Explicit implementation - Syrup.Encoder","doc":"If you wish to implement the protocol fully yourself, it is advised to\nuse functions from the `Syrup.Encode` module to do the actual encoding.\nThey are highly optimized and verified to always produce valid Syrup.","ref":"Syrup.Encoder.html#module-explicit-implementation"},{"type":"function","title":"Syrup.Encoder.encode!/2","doc":"Encodes `value` to Syrup.\n\nThe argument `opts` is opaque - it can be passed to various functions in\n`Syrup.Encode` (or to the protocol function itself) for encoding values to Syrup.","ref":"Syrup.Encoder.html#encode!/2"},{"type":"type","title":"Syrup.Encoder.opts/0","doc":"","ref":"Syrup.Encoder.html#t:opts/0"},{"type":"type","title":"Syrup.Encoder.t/0","doc":"","ref":"Syrup.Encoder.html#t:t/0"},{"type":"module","title":"Syrup.Record","doc":"A record is a labeled tuple representing an Elixir struct.\n\nDeclaring a Syrup record defines a struct with the arguments and a Syrup encoder using the record format.\n\nExample:\n\n    defmodule MyRecord do\n      use Syrup.Record\n\n      syrup do\n        label :my_record\n        argument :name, :string, public?: true\n      end\n    end\n\n    record = %MyRecord{name: \"foo\"}\n    assert Syrup.decode!(Syrup.encode!(record)) == {:my_record, \"foo\"}\n\n    MyRecord.from_syrup_record({:my_record, \"foo\"}) == {:ok, %MyRecord{name: \"foo\"}}\n    MyRecord.from_syrup(Syrup.encode!(record)) == {:ok, %MyRecord{name: \"foo\"}}\n\nArguments must be marked as `public?` to be serialized by Syrup. The default is `false` (not to include it) so that the inclusion of data in the serialization is a deliberate choice.","ref":"Syrup.Record.html"},{"type":"module","title":"Options - Syrup.Record","doc":"* `:fragments` (list of `t:module/0`) - Fragments to include in the `Spark.Dsl`. See the fragments guide for more.","ref":"Syrup.Record.html#module-options"},{"type":"module","title":"Syrup.Record.Info","doc":"","ref":"Syrup.Record.Info.html"},{"type":"function","title":"Syrup.Record.Info.syrup/1","doc":"syrup DSL entities","ref":"Syrup.Record.Info.html#syrup/1"},{"type":"function","title":"Syrup.Record.Info.syrup_label/1","doc":"The Syrup label of the record.","ref":"Syrup.Record.Info.html#syrup_label/1"},{"type":"function","title":"Syrup.Record.Info.syrup_label!/1","doc":"The Syrup label of the record.","ref":"Syrup.Record.Info.html#syrup_label!/1"},{"type":"function","title":"Syrup.Record.Info.syrup_options/1","doc":"syrup DSL options\n\nReturns a map containing the and any configured or default values.","ref":"Syrup.Record.Info.html#syrup_options/1"},{"type":"module","title":"Syrup.Record.Transformers.RequireUniqueFieldNames","doc":"Confirms that a record does not have multiple fields or calculations with the same name.","ref":"Syrup.Record.Transformers.RequireUniqueFieldNames.html"},{"type":"function","title":"Syrup.Record.Transformers.RequireUniqueFieldNames.after?/1","doc":"","ref":"Syrup.Record.Transformers.RequireUniqueFieldNames.html#after?/1"},{"type":"function","title":"Syrup.Record.Transformers.RequireUniqueFieldNames.after_compile?/0","doc":"","ref":"Syrup.Record.Transformers.RequireUniqueFieldNames.html#after_compile?/0"},{"type":"function","title":"Syrup.Record.Transformers.RequireUniqueFieldNames.before?/1","doc":"","ref":"Syrup.Record.Transformers.RequireUniqueFieldNames.html#before?/1"},{"type":"function","title":"Syrup.Record.Transformers.RequireUniqueFieldNames.transform/1","doc":"","ref":"Syrup.Record.Transformers.RequireUniqueFieldNames.html#transform/1"},{"type":"exception","title":"Syrup.DecodeError","doc":"","ref":"Syrup.DecodeError.html"},{"type":"function","title":"Syrup.DecodeError.new/1","doc":"","ref":"Syrup.DecodeError.html#new/1"},{"type":"type","title":"Syrup.DecodeError.t/0","doc":"","ref":"Syrup.DecodeError.html#t:t/0"},{"type":"exception","title":"Syrup.EncodeError","doc":"Errors arising from encoding values to Syrup.","ref":"Syrup.EncodeError.html"},{"type":"function","title":"Syrup.EncodeError.new/1","doc":"","ref":"Syrup.EncodeError.html#new/1"},{"type":"type","title":"Syrup.EncodeError.t/0","doc":"","ref":"Syrup.EncodeError.html#t:t/0"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG","ref":"changelog.html"},{"type":"extras","title":"0.3.0 - CHANGELOG","doc":"- Breaking change: `argument` is now `field` to better align with how we talk about `struct`s.","ref":"changelog.html#0-3-0"},{"type":"extras","title":"0.2.0 - CHANGELOG","doc":"- Added Spark-based DSL to create Syrup records as Elixir structs. See `Syrup.Record` for details.\n- Fixed serializing structs as records. Field names should not be part of the serialization.","ref":"changelog.html#0-2-0"},{"type":"extras","title":"0.1.0 - Initial release - CHANGELOG","doc":"","ref":"changelog.html#0-1-0-initial-release"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}